DerivedGeometryRun class final

Immutable provenance for one post-capture geometry derivation.

Constructors

DerivedGeometryRun({required String id, required String trackId, required String name, required String algorithm, required String algorithmVersion, required Map<String, Object?> configuration, required int sourceMaximumSequence, required DerivedGeometryRunStatus status, required DateTime createdAt, DateTime? completedAt, int pointCount = 0, String? mapDataSource, String? mapDataVersion, String? failureCode})

Properties

algorithm String
final
algorithmVersion String
final
completedAt DateTime?
final
configuration UnmodifiableMapView<String, Object?>
final
createdAt DateTime
final
failureCode String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
mapDataSource String?
final
mapDataVersion String?
final
name String
final
pointCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceMaximumSequence int
final
status DerivedGeometryRunStatus
final
trackId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited