LocationPermissionLevel enum

Normalized foreground/background location authorization level.

Inheritance
Available extensions

Values

unknown → const LocationPermissionLevel

Authorization has not been determined or could not be read.

denied → const LocationPermissionLevel

Location authorization is currently denied.

deniedForever → const LocationPermissionLevel

Authorization requires a manual change in system settings.

whileInUse → const LocationPermissionLevel

Location is allowed only while the app is in use.

always → const LocationPermissionLevel

Location is authorized for background tracking.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LocationPermissionLevel>
A constant List of the values in this enum, in order of their declaration.