LocationSample class final

Constructors

LocationSample({required double latitude, required double longitude, required DateTime capturedAt, double? altitude, double? horizontalAccuracy, double? verticalAccuracy, double? speed, double? speedAccuracy, double? heading, double? headingAccuracy, bool isMocked = false, bool mockDetectionAvailable = false, bool? isProducedByAccessory, String? mockEvidence, String? provider, String? eventId, String? trackId, ActivitySnapshot? capturedActivity, MotionState? capturedMotionState})
const
LocationSample.fromMap(Map<Object?, Object?> map)
factory

Properties

altitude double?
final
capturedActivity ActivitySnapshot?
final
capturedAt DateTime
final
capturedMotionState MotionState?
final
eventId String?
final
hashCode int
The hash code for this object.
no setterinherited
heading double?
final
headingAccuracy double?
final
horizontalAccuracy double?
final
isMocked bool
final
isProducedByAccessory bool?
final
latitude double
final
longitude double
final
mockAssessment MockLocationAssessment
no setter
mockDetectionAvailable bool
final
mockEvidence String?
final
provider String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double?
final
speedAccuracy double?
final
trackId String?
The native session that produced this fix, when supplied by the adapter.
final
verticalAccuracy double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited