TrackLifecycleResult class final

Track plus status snapshot returned by pause and complete operations.

Constructors

TrackLifecycleResult({required Track track, required TrackerStatus status})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status TrackerStatus
Status after the lifecycle operation completed.
final
track Track
Track affected by the lifecycle operation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited