TrackUploadAcknowledgement class final

Constructors

TrackUploadAcknowledgement({required int acceptedThroughSequence, List<int> rejectedSequences = const <int>[]})
const

Properties

acceptedThroughSequence int
final
hashCode int
The hash code for this object.
no setterinherited
rejectedSequences List<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited