TrackUploadBatch class final

Constructors

TrackUploadBatch({required String trackId, required int firstSequence, required int lastSequence, required String idempotencyKey, required List<TrackPoint> points})
const

Properties

encodedByteLength int
no setter
firstSequence int
final
hashCode int
The hash code for this object.
no setterinherited
idempotencyKey String
final
lastSequence int
final
points List<TrackPoint>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Canonical transport-shaped representation used for encoded byte limits.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited