AdaptiveBatteryObservation class final
Coordinate-free inputs supplied by the host/platform integration.
Constructors
- AdaptiveBatteryObservation({required DateTime observedAt, int? batteryPercent, bool? charging, bool lowPowerMode = false, AdaptiveThermalState thermalState = AdaptiveThermalState.unavailable, TrackingActivityType activityType = TrackingActivityType.unknown, int activityConfidence = 0, Duration stationaryDwell = Duration.zero, double? recentFixAccuracyMeters, int? pendingNativeEvents})
-
const
Properties
- activityConfidence → int
-
final
- activityType → TrackingActivityType
-
final
- batteryPercent → int?
-
final
- charging → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lowPowerMode → bool
-
final
- observedAt → DateTime
-
final
- pendingNativeEvents → int?
-
final
- recentFixAccuracyMeters → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stationaryDwell → Duration
-
final
- thermalState → AdaptiveThermalState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited