InferredRouteConnector class final
Presentation-only straight connector between two captured anchors.
Constructors
- InferredRouteConnector({required String beforePointId, required String afterPointId, required String beforeSegmentId, required String afterSegmentId, required TrackingGapCause cause, required Duration duration, required double straightLineDistanceMeters, required int beforeLegNumber, required int afterLegNumber})
-
const
Properties
- afterLegNumber → int
-
final
- afterPointId → String
-
final
- afterSegmentId → String
-
final
- beforeLegNumber → int
-
final
- beforePointId → String
-
final
- beforeSegmentId → String
-
final
- cause → TrackingGapCause
-
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- straightLineDistanceMeters → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited