TrackExportResultV2 class final
Result of a V2 export with a share-safe destination abstraction.
Constructors
- TrackExportResultV2({required String managedExportId, required String trackId, required TrackExportFormat format, required TrackExportDestination destination, required int byteLength, required int pointCount, required int segmentCount, int gapCount = 0, int inferredConnectorCount = 0, RouteGeometryContinuity geometryContinuity = RouteGeometryContinuity.preserveEvidenceSegments, int? sourceSegmentCount, int? geometryPartCount})
-
const
Properties
- byteLength → int
-
final
- destination → TrackExportDestination
-
final
- format → TrackExportFormat
-
final
- gapCount → int
-
final
- geometryContinuity → RouteGeometryContinuity
-
final
- geometryPartCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inferredConnectorCount → int
-
final
- managedExportId → String
-
Owner-scoped canonical inventory identifier for this artifact.
final
- pointCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentCount → int
-
final
- sourceSegmentCount → int
-
final
- trackId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited