TrackExportServiceV2 class final
Owner-bound, bounded-memory V2 route export service.
Android writes incrementally to public Downloads through MediaStore (or an atomic pre-Q file). Other platforms write an atomic local file. The result never presents a content URI as a filesystem path.
- Implemented types
Constructors
- TrackExportServiceV2({required TrackRepository repository, required TrackingOwner owner, String directoryName = 'flutter_background_location', MethodChannel? methodChannel, ExportDirectoryProvider? exportDirectoryProvider, bool isOwnerScopeCurrent()?, bool? useAndroidNativeDestination, })
Properties
- directoryName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- owner → TrackingOwner
-
final
- repository → TrackRepository
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
Methods
-
deleteManagedExport(
String exportId) → Future< ManagedExportDeletionReport> -
override
-
exportTrackV2(
TrackExportRequest request) → Future< TrackExportOperation> -
override
-
listManagedExports(
String trackId) → Future< List< ManagedTrackExport> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareExportForSharing(
TrackExportResultV2 result) → Future< PreparedTrackShareFile> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited