TrackStatus enum
Durable lifecycle state of one recorded route.
Values
- starting → const TrackStatus
-
Route metadata exists while native capture is being prepared.
- active → const TrackStatus
-
Route location capture is active.
- paused → const TrackStatus
-
Route is retained and can be resumed without collecting points.
- stopping → const TrackStatus
-
Route is completing native and database cleanup.
- completed → const TrackStatus
-
Route was completed normally.
- interrupted → const TrackStatus
-
Route capture stopped unexpectedly and can be resumed.
- failed → const TrackStatus
-
Route ended with a terminal failure.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TrackStatus> - A constant List of the values in this enum, in order of their declaration.