TrackingSupportReport class final
Sanitized support data with no route/owner IDs, coordinates, filenames, command tokens, or raw native exception details.
Constructors
-
TrackingSupportReport({required DateTime createdAt, required int protocolVersion, required Iterable<
String> capabilities, required TrackingHealthSnapshot health, required BatteryOptimizationState batteryOptimization})
Properties
- batteryOptimization → BatteryOptimizationState
-
final
-
capabilities
→ UnmodifiableListView<
String> -
final
- createdAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- health → TrackingHealthSnapshot
-
final
- protocolVersion → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toRedactedMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited