UploadOutboxEntry class final
A durable upload task stored alongside its track.
Constructors
- UploadOutboxEntry({required String id, required String trackId, required UploadOutboxKind kind, required String idempotencyKey, required UploadOutboxState state, required int attemptCount, required DateTime nextAttemptAt, required DateTime createdAt, required DateTime updatedAt, int? firstSequence, int? lastSequence, String? lastError, String? leaseOwner, DateTime? leaseExpiresAt})
-
const
Properties
- attemptCount → int
-
final
- createdAt → DateTime
-
final
- firstSequence → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- idempotencyKey → String
-
final
- kind → UploadOutboxKind
-
final
- lastError → String?
-
final
- lastSequence → int?
-
final
- leaseExpiresAt → DateTime?
-
final
- leaseOwner → String?
-
final
- nextAttemptAt → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → UploadOutboxState
-
final
- trackId → String
-
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited