DeterministicTrackingClock class final
A wall and monotonic clock that advances only when the test asks it to.
Constructors
- DeterministicTrackingClock({DateTime? initialTime, int initialMonotonicNanos = 0})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
advance(
Duration duration) → void -
call(
) → DateTime -
monotonicNanos(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited